@@ -11,7 +11,7 @@ use vars qw(@EXPORT @EXPORT_OK @ISA $VERSION);
 BEGIN {
     require Exporter;
     @ISA = qw(Exporter);
-    $VERSION = '1.05';
+    $VERSION = '1.06';
     @EXPORT = @EXPORT_OK = qw(rd_f wr_f ap_f find_home find_temp find_bin lockafile unlockafile unlock_all_the_files);
 }
 
@@ -100,15 +100,17 @@ sub rd_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '<:raw:bytes', $fn)) {
+    unless (open($fh, '< :raw :bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for reading", $!, 0+$!);
         return undef;
     }
     binmode($fh);
     my $file_size = -s $fn;
-    if ($file_size) {
-        my $n_bytes = read($fh, $buf, $file_size);
-        close($fh);
+    if (defined $file_size && $file_size == 0) {
+        $buf = '';
+    }
+    elsif (defined $file_size) {
+        my $n_bytes = sysread($fh, $buf, $file_size);
         if (!defined($n_bytes)) {
             ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'read failed', $!, 0+$!);
             return undef;
@@ -119,13 +121,17 @@ sub rd_f {
         }
     }
     else {
-        local $/;
-        if (!defined($buf = readline($fh))) {
+        my $res = sysread($fh, $buf, 0xFFFFFFFF);
+        if (!defined $res) {
             ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'read failed', $!, 0+$!);
             return undef;
         }
     }
-    close($fh);
+    my $res = close($fh);
+    unless ($res) {
+        ($OK, $ERROR, $ERRNO, $ERRNUM) = ('WARNING', 'close failed', $!, 0+$!);
+        return undef;
+    }
     ($OK, $ERROR, $ERRNO, $ERRNUM) = ('OK', '', '', 0);
     return $buf;
 }
@@ -138,16 +144,21 @@ sub wr_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '>:raw:bytes', $fn)) {
+    unless (open($fh, '> :raw :bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for writing", $!, 0+$!);
         return undef;
     }
     binmode($fh);
-    unless (print $fh $buf) {
+    my $res = syswrite($fh, $buf);
+    unless (defined $res) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'write error', $!, 0+$!);
         return undef;
     }
-    close($fh);
+    $res = close($fh);
+    unless ($res) {
+        ($OK, $ERROR, $ERRNO, $ERRNUM) = ('WARNING', 'close failed', $!, 0+$!);
+        return undef;
+    }
     ($OK, $ERROR, $ERRNO, $ERRNUM) = ('OK', '', '', 0);
     return 'OK';
 }
@@ -160,16 +171,21 @@ sub ap_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '>>:raw:bytes', $fn)) {
+    unless (open($fh, '>> :raw :bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for appending", $!, 0+$!);
         return undef;
     }
     binmode($fh);
-    unless (print $fh $buf) {
-        ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'append error', $!, 0+$!);
+    my $res = syswrite($fh, $buf);
+    unless (defined $res) {
+        ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'write error', $!, 0+$!);
+        return undef;
+    }
+    $res = close($fh);
+    unless ($res) {
+        ($OK, $ERROR, $ERRNO, $ERRNUM) = ('WARNING', 'close failed', $!, 0+$!);
         return undef;
     }
-    close($fh);
     ($OK, $ERROR, $ERRNO, $ERRNUM) = ('OK', '', '', 0);
     return 'OK';
 }
